======
Client
======

aiosend is |python| python implementation for `Crypto Pay API <https://help.crypt.bot/crypto-pay-api>`_.

* **Methods** - official Crypto Pay API methods.
* **Tools** - additional functionality.
* **Webhook** - updates handling via webhook.
* **Invoice polling** - invoice updates handling via polling.
* **Check polling** - check updates handling via polling.


.. |python| image:: ../_static/python.png
    :width: 16px
    :alt: python

.. toctree::

    methods
    tools
    webhook
    invoice_polling
    check_polling
    polling_config